@@ -1,6 +1,6 @@
 // -*- mode: cpp; mode: fold -*-
 // Description								/*{{{*/
-// $Id: apt-get.cc,v 1.77 1998/09/12 01:16:37 jgg Exp $
+// $Id: apt-get.cc,v 1.78 1998/11/20 01:51:08 jgg Exp $
 /* ######################################################################
    
    apt-get - Cover for dpkg
@@ -70,6 +70,7 @@ bool NoAct = false;
 bool AssumeY = false;
 bool FixBroken = false;
 bool FixMissing = false;
+int NoUpgrade = 0;
 int ScreenWidth = 78;
 									/*}}}*/
 // Prototypes								/*{{{*/
@@ -965,6 +966,14 @@ bool Install(pkgSourceList &List,int argc,char *argv[])
       if (Pkg.end() == true)
 	 return _error->Error("Couldn't find package %s",S);
       
+      // Handle the no-upgrade case
+      if (NoUpgrade == 1 && Pkg->CurrentVer != 0)
+      {
+	 if (Quiet < 2)
+	   cout << "Skipping " << Pkg.Name() << ", it is already installed and no-upgrade is set." << endl;
+	 continue;
+      }
+      
       // Check if there is something new to install
       pkgDepCache::StateCache &State = (*Dep)[Pkg];
       if (State.CandidateVer == 0)
@@ -1209,6 +1218,7 @@ bool ProcessOptions(int argc,char *argv[])
       {"assume-yes",no_argument,0,'y'},
       {"fix-broken",no_argument,0,'f'},
       {"ignore-missing",no_argument,0,'m'},
+      {"no-upgrade",no_argument,&NoUpgrade,1},      
       {0,0,0,0}};
       
    while ((Opt = getopt_long(argc,argv,"hqsdyfm",long_options,0)) != EOF)
